/* inc/config.h.  Generated from config.h.in by configure.  */
#ifndef _FF_CONFIG_H
# define _FF_CONFIG_H	1

#define HAVE_DLFCN_H 1
/* #undef _NO_PYTHON */
#define HAVE_ICONV_H 1
#define HAVE_STDINT_H 1
#define HAVE_LANGINFO_H 1
#define HAVE_PTHREAD_H 1
#define HAVE_LIBINTL_H 1
#define HAVE_IEEEFP_H 1
/* #undef FREETYPE_HAS_DEBUGGER */
/* #undef HAVE_LONG_DOUBLE */
#define _HAS_LONGLONG 1
#define HAVE_LIBINTL_H 1
#define _STATIC_LIBINTL 1
/* #undef _STATIC_LIBUNGIF */
/* #undef _STATIC_LIBPNG */
/* #undef _STATIC_LIBPNG12 */
/* #undef _STATIC_LIBTIFF */
/* #undef _STATIC_LIBJPEG */
/* #undef _STATIC_LIBSPIRO */
/* #undef _STATIC_LIBXML2 */
/* #undef _STATIC_LIBFREETYPE */
/* #undef _STATIC_LIBUNINAMESLIST */
/* #undef _STATIC_LIBCAIRO */
#define _NO_LIBUNINAMESLIST 1
/* #undef SHAREDIR */
/* #undef LIBDIR */
/* #undef PREFIX */
/* #undef _CursorsMustBe16x16 */
/* #undef _Keyboard */
/* #undef __Mac */
/* #undef _BrokenBitmapImages */
/* #undef _ModKeysAutoRepeat */
/* #undef __CygWin */
/* #undef _NO_XINPUT */
/* #undef FONTFORGE_CONFIG_CAPSLOCK_FOR_ALT */
/* #undef FONTFORGE_CONFIG_SHOW_RAW_POINTS */
/* #undef FONTFORGE_CONFIG_TYPE3 */
#define FONTFORGE_CONFIG_DEVICETABLES 1
/* #undef FONTFORGE_CONFIG_USE_DOUBLE */
/* #undef FONTFORGE_CONFIG_USE_LONGDOUBLE */
/* #undef FONTFORGE_CONFIG_PASTEAFTER */
/* #undef FONTFORGE_CONFIG_GB12345 */
/* #undef FONTFORGE_CONFIG_TILEPATH */
/* #undef _NO_FFSCRIPT */
/* #undef _NO_TZSET */
/* #undef _NO_FREETYPE */
/* #undef _NO_LIBXML */
/* #undef _NO_LIBUNGIF */
/* #undef _NO_LIBPNG */
/* #undef _LIBPNG12 */
/* #undef _NO_LIBJPEG */
/* #undef _NO_LIBTIFF */
/* #undef _NO_LIBSPIRO */
#define NODYNAMIC 1
/* #undef FREETYPE_HAS_DEBUGGER */
/* #undef _NO_SNPRINTF */
#define _NO_XKB 1
/* #undef X_DISPLAY_MISSING */
#define PYTHON_LIB_NAME "python2.7"
/* #undef _NO_LIBCAIRO */
/* #undef _NO_LIBPANGO */
#define WORDS_BIGENDIAN 1

#endif
